@@ -1,3 +1,19 @@
+"""
+    flask_user.emails
+    -----------------
+    This module contains Flask-User functions that deal with sending emails.
+
+    It uses Jinja2 to render email subject and email message.
+    It uses Flask-Mail to send email.
+
+    :copyright: (c) 2013 by Ling Thio
+    :author: Ling Thio (ling.thio@gmail.com)
+    :license: Simplified BSD License, see LICENSE.txt for more details.
+"""
+
+import smtplib
+import socket
+
 from flask import current_app, render_template, url_for
 from flask_mail import Message
 
@@ -18,12 +34,31 @@ def _render_email(email_name, **kwargs):
 
     return (subject, html_message, text_message)
 
+def _send_email(recipient, subject, html_message, text_message):
+    class EmailException(Exception):
+        pass
+
+    # Construct Flash-Mail message
+    message = Message(subject,
+            recipients=[recipient],
+            html = html_message,
+            body = text_message)
+
+    # Send email using Flash-Mail
+    try:
+        current_app.mail.send(message)
+    except (socket.gaierror, socket.error) as e:
+        raise EmailException('Connection error: Check your MAIL_HOSTNAME or MAIL_PORT settings.')
+    except smtplib.SMTPAuthenticationError:
+        raise EmailException('SMTP Authentication error: Check your MAIL_USERNAME and MAIL_PASSWORD settings.')
+
+
 
 def send_confirmation_email(email, user, token):
     # Verify certain conditions
     user_manager =  current_app.user_manager
     assert email
-    assert user_manager.require_email_confirmation
+    assert user_manager.enable_confirm_email
 
     # Generate confirmation link
     confirmation_link = url_for('user.confirm_email', token=token, _external=True)
@@ -32,14 +67,8 @@ def send_confirmation_email(email, user, token):
     subject, html_message, text_message = _render_email('confirmation',
             user=user, confirmation_link=confirmation_link)
 
-    # Construct Flash-Mail message
-    message = Message(subject,
-            recipients=[email],
-            body = text_message,
-            html = html_message)
-
-    # Send message
-    current_app.mail.send(message)
+    # Send email message using Flask-Mail
+    _send_email(email, subject, html_message, text_message)
 
 
 def send_reset_password_email(email, user, token):
@@ -48,9 +77,6 @@ def send_reset_password_email(email, user, token):
     assert email
     assert user_manager.enable_forgot_password
 
-    # For debug only
-    email = 'ling.thio@gmail.com'
-
     # Generate confirmation link
     reset_password_link = url_for('user.reset_password', token=token, _external=True)
 
@@ -59,11 +85,5 @@ def send_reset_password_email(email, user, token):
             user=user,
             reset_password_link=reset_password_link)
 
-    # Construct Flash-Mail message
-    message = Message(subject,
-            recipients=[email],
-            body = text_message,
-            html = html_message)
-
-    # Send message
-    current_app.mail.send(message)
+    # Send email message using Flask-Mail
+    _send_email(email, subject, html_message, text_message)
